-- DSER-2973; postgres backed AD and other group metadata info data storage
CREATE TABLE IF NOT EXISTS group_set (
  org_id BIGINT NOT NULL,
  last_update_time timestamp,
  last_process_time timestamp,
  last_in_progress_time timestamp,
  PRIMARY KEY (org_id)
);

-- DSER-2973; postgres backed AD and other group metadata info data storage
CREATE TABLE IF NOT EXISTS group_position (
  org_id BIGINT NOT NULL,
  group_id BIGINT NOT NULL,
  position int NOT NULL,
  PRIMARY KEY (org_id, group_id)
);

-- DSER-2973; postgres backed AD and other group metadata info data storage
CREATE TABLE IF NOT EXISTS groups (
  id SERIAL,
  org_id BIGINT NOT NULL,
  name text NOT NULL,
  rules text NOT NULL,
  operation int NOT NULL,
  policy_id BIGINT NOT NULL,
  PRIMARY KEY (org_id, name)
);

-- DSER-2973; postgres backed AD and other group metadata info data storage
CREATE TABLE IF NOT EXISTS org_meta_data (
  id SERIAL,
  org_id BIGINT NOT NULL,
  key text NOT NULL,
  value text NOT NULL,
  position int NOT NULL,
  PRIMARY KEY (org_id, key, value, position)
);

-- DSER-2973; postgres backed AD and other group metadata info data storage
CREATE TABLE IF NOT EXISTS device_meta_data (
  device_id BIGINT NOT NULL,
  org_meta_data_id BIGINT NOT NULL,
  PRIMARY KEY (device_id, org_meta_data_id)
);

-- DSER-2973; postgres backed AD and other group metadata info data storage
CREATE TABLE IF NOT EXISTS device_groups (
  device_id BIGINT NOT NULL,
  group_id BIGINT NOT NULL,
  position int NOT NULL,
  PRIMARY KEY (device_id, group_id)
);

-- DSER-2973; postgres backed AD and other group metadata info data storage
CREATE TABLE IF NOT EXISTS policy_groups (
  policy_id BIGINT NOT NULL,
  group_id BIGINT NOT NULL,
  PRIMARY KEY (policy_id, group_id)
);

CREATE INDEX groups_id_index ON groups (id);
CREATE INDEX groups_policy_id_index ON groups (policy_id);
CREATE INDEX org_meta_data_id_index ON org_meta_data (id);

--
-- Changes for DSER-3483 - Changing device_id column type to bigint
--
ALTER TABLE device ALTER COLUMN replica_device_id TYPE bigint;
ALTER TABLE device ALTER COLUMN device_id TYPE bigint;
ALTER TABLE device_group_device ALTER COLUMN device_id TYPE bigint;
--
-- These tables below are currently not used - updating for consistency
--
ALTER TABLE file_upload ALTER COLUMN device_id TYPE bigint;
ALTER TABLE org_safe_device ALTER COLUMN device_id TYPE bigint;
ALTER TABLE behavior_event ALTER COLUMN device_id TYPE bigint;
--
-- End of DSER-3483 change
--

-- DSER-3092; MSSP Single Sign On
CREATE TABLE IF NOT EXISTS org_control_delegation (
  controlling_org_id BIGINT NOT NULL REFERENCES organization(org_id),
  org_id BIGINT NOT NULL REFERENCES organization(org_id)
);

CREATE UNIQUE INDEX org_control_delegation_index ON org_control_delegation (controlling_org_id, org_id);
