-- Table of TH rulesets
CREATE TABLE IF NOT EXISTS threathunter_ruleset (
  ruleset_id SERIAL NOT NULL PRIMARY KEY,
  created_at TIMESTAMP NOT NULL,
  with_ubs JSON NOT NULL,
  without_ubs JSON NOT NULL,
  note VARCHAR(255)
);

CREATE INDEX threathunter_ruleset_ruleset_id_index ON threathunter_ruleset (ruleset_id);


-- Pre-populate the default TH Rulesets
-- Ensures that they will be at ID 1 and can never be null
-- Does not-duplicate the inserts on case of re-running the migration

DO
$do$
BEGIN

IF NOT EXISTS(SELECT ruleset_id from threathunter_ruleset WHERE ruleset_id = 0) THEN
  INSERT INTO threathunter_ruleset (ruleset_id, created_at, with_ubs, without_ubs, note)
  VALUES (
             0,
             now(),
             '{
        "$schema": "http://json-schema.org/schema#",
        "id": "CbPscThAndUbsRules-2018-12-03.json",
        "Version": "1.0",
        "DynamicMatchTypes": [
            {
                "AttributeId": "FileResourceCompany",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info[\"CompanyName\"]",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourceProduct",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info[\"ProductName\"]",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourceInternalName",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info[\"InternalName\"]",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourceCopyright",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info[\"LegalCopyright\"]",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourceTrademark",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info[\"LegalTrademarks\"]",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourceFileDescription",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info[\"FileDescription\"]",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourceVersion",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info[\"FileVersion\"]",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourceComments",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info[\"Comments\"]",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourceOriginalFilename",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info[\"OriginalFilename\"]",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourceProductDescription",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info[\"ProductDescription\"]",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourcePrivateBuild",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info[\"PrivateBuild\"]",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourceSpecialBuild",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info[\"SpecialBuild\"]",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourceProductVersion",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info[\"ProductVersion\"]",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileArchitecture",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.machine",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourceLangId",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info_lang_id",
                "EventObjectType": "File"
            },
            {
                "AttributeId": "FileResourceCharsetId",
                "ExternalModuleName": "yara",
                "ExternalModuleCallArguments": "pe.version_info_charset_id",
                "EventObjectType": "File"
            }
        ],
        "Policies": [
            {
                "GUID": "19EF3154-298C-4257-B2E0-CB548FDD8909",
                "ProductGUIDs": [
                    "E7A89D11-37FC-4EC1-BB62-34C28CF14221"
                ],
                "Description": "PSC Response Policy",
                "Revision": 10,
                "PolicyTags": "PSCR",
                "Enabled": true,
                "EventCheckRules": [
                    {
                        "Description": "Report file create, open for w/d, delete, undelete and rename for files without signer metadata",
                        "GUID": "3D31EB6E-EF60-416A-B931-437F9D274821",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessFileModCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "Comment": "Since STATUS_REPARSE is ignored by the sensor, we can write the rule to be NT_SUCCESS(status)",
                                "AttributeId": "Disposition",
                                "GTE": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "FILE_CREATE",
                                    "FILE_OPEN_WRITE",
                                    "FILE_OPEN_DELETE",
                                    "FILE_DELETE",
                                    "FILE_UNDELETE",
                                    "FILE_RENAME",
                                    "FILE_TRUNCATE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "File"
                            }
                        ],
                        "Target": [
                            {
                                "AttributeId": "FileType",
                                "Equals": [
                                    "FILE_TYPE_EXECUTABLE_IMAGE",
                                    "FILE_TYPE_EXECUTABLE_DLL"
                                ],
                                "Exclude": true
                            },
                            {
                                "AttributeId": "FileExtension",
                                "Equals": [
                                    "ps1",
                                    "psm1",
                                    "cdxml",
                                    "msi",
                                    "msp",
                                    "mst"
                                ],
                                "Exclude": true
                            }
                        ]
                    },
                    {
                        "Description": "Report file create, open for w/d, delete, undelete and rename for PE files",
                        "GUID": "DD0C81A3-04D3-453E-AF99-56AB86F577A0",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessFileModCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "Comment": "Since STATUS_REPARSE is ignored by the sensor, we can write the rule to be NT_SUCCESS(status)",
                                "AttributeId": "Disposition",
                                "GTE": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "FILE_CREATE",
                                    "FILE_OPEN_WRITE",
                                    "FILE_OPEN_DELETE",
                                    "FILE_DELETE",
                                    "FILE_UNDELETE",
                                    "FILE_RENAME",
                                    "FILE_TRUNCATE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "File"
                            }
                        ],
                        "Target": [
                            {
                                "AttributeId": "FileType",
                                "Equals": [
                                    "FILE_TYPE_EXECUTABLE_IMAGE",
                                    "FILE_TYPE_EXECUTABLE_DLL"
                                ]
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report file create, open for w/d, delete, undelete and rename for non-PE files that can have signer data",
                        "GUID": "0B32C6E5-A01D-41C5-A6E2-86AFEAFDD460",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessFileModCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "Comment": "Since STATUS_REPARSE is ignored by the sensor, we can write the rule to be NT_SUCCESS(status)",
                                "AttributeId": "Disposition",
                                "GTE": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "FILE_CREATE",
                                    "FILE_OPEN_WRITE",
                                    "FILE_OPEN_DELETE",
                                    "FILE_DELETE",
                                    "FILE_UNDELETE",
                                    "FILE_RENAME",
                                    "FILE_TRUNCATE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "File"
                            }
                        ],
                        "Target": [
                            {
                                "AttributeId": "FileExtension",
                                "Equals": [
                                    "ps1",
                                    "psm1",
                                    "cdxml",
                                    "msi",
                                    "msp",
                                    "mst"
                                ]
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report file last write",
                        "GUID": "3D2396F4-71AC-496A-9A5A-53A6ECC7AD1A",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Set 1 or Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessFileModCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "FILE_LAST_WRITE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "File"
                            }
                        ],
                        "Target": [
                            {
                                "Comment": "Restrict matches to executable file types (UAV-564)",
                                "AttributeId": "FileType",
                                "Equals": [
                                    "FILE_TYPE_EXECUTABLE_IMAGE",
                                    "FILE_TYPE_EXECUTABLE_DLL"
                                ]
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report registry operations",
                        "GUID": "219833E7-914E-4E0E-886C-63E7DE7853EC",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessRegModCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Disposition",
                                "Equals": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "REG_CREATE_KEY",
                                    "REG_DELETE_KEY",
                                    "REG_DELETE_VALUE",
                                    "REG_WRITE_VALUE",
                                    "REG_RENAME_KEY",
                                    "REG_REPLACE_KEY",
                                    "REG_RESTORE_KEY",
                                    "REG_LOAD_KEY"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Registry"
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "RegKeyValuePath"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "RegNewKeyPath"
                            }
                        ]
                    },
                    {
                        "Description": "Report process create operations",
                        "GUID": "7B209D10-FD28-469f-8912-F16D0C34433D",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessCreateCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "State Set",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": [
                                    "ProcessModuleLoadCount",
                                    "ProcessFileModCount",
                                    "ProcessNetConnCount",
                                    "ProcessRegModCount",
                                    "ProcessCreateCount",
                                    "ProcessCrossProcessCount",
                                    "ProcessCrossProcessTargetCount"
                                ],
                                "Actor": "Target",
                                "StateValue": 0
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Disposition",
                                "Equals": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "CREATE_PROCESS",
                                    "PROCESS_DISCOVERED"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Process"
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report process termination",
                        "GUID": "6D0B2BF2-BD3B-4768-8E51-2C350985BBB7",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Set 1 or Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessCrossProcessCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "AttributeId": "ProcessID",
                                "NotEquals": 0
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "PROCESS_TERMINATE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Process"
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report process and thread operations",
                        "GUID": "0E5F8A39-1BB2-4A4E-942E-2618A41ABB24",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessCrossProcessCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessCrossProcessTargetCount",
                                "Actor": "Target"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "AttributeId": "FilePath",
                                "Exclude": true,
                                "Equals": "<System>\\csrss.exe"
                            },
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Disposition",
                                "Equals": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "OPEN_PROCESS_HANDLE",
                                    "OPEN_THREAD_HANDLE",
                                    "DUP_PROCESS_HANDLE",
                                    "DUP_THREAD_HANDLE",
                                    "CREATE_REMOTE_THREAD"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Process"
                            }
                        ],
                        "TargetParent": [
                            {
                                "AttributeId": "IsInitiator",
                                "Exclude": true,
                                "Equals": true
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report module and script load operations",
                        "GUID": "6F04362F-23BA-45E0-875A-BB686EA7F65C",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessModuleLoadCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "AttributeId": "ProcessID",
                                "NotEquals": 0
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Disposition",
                                "GTE": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "LOAD_IMAGE",
                                    "LOAD_SCRIPT"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Module"
                            }
                        ],
                        "Target": [
                            {
                                "Comment": "Suppress known dll modload events (UAV-502)",
                                "AttributeId": "IsKnownDll",
                                "NotEquals": true
                            },
                            {
                                "Comment": "Suppress process image modload event (UAV-395)",
                                "AttributeId": "FilePath",
                                "CompareValues": {
                                    "NotEqualsCaseSensitive": {
                                        "Actor": "Initiator",
                                        "AttributeId": "FilePath"
                                    }
                                }
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report network operations",
                        "GUID": "FDDAD7FC-9B5A-4BAC-AE2E-EA841AF6B27A",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessNetConnCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "Comment": "maps to Pb evnets: ACTION_CONNECTION_CREATE, ACTION_CONNECTION_CREATE_FAILED (UAV-552)",
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "NET_ACCEPT",
                                    "NET_CONNECT",
                                    "NET_CONNECT_FAILED"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Network"
                            }
                        ],
                        "Target": [
                            {
                                "AttributeId": "IpProtocol",
                                "Equals": 6
                            },
                            {
                                "AttributeId": "IpProtocol",
                                "Equals": 17
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "IpProtocol"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "LocalPort"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "RemotePort"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "Fqdn"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "NetworkFlags"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "IpProtoVersion"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "LocalIpAddress"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "RemoteIpAddress"
                            }
                        ]
                    },
                    {
                        "Description": "Report network listen",
                        "GUID": "EDDAD7FC-9B5A-4BAC-AE2E-EA841AF6B27A",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessNetConnCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "ValuesOf": [
                                        {
                                            "Actor": "Operation",
                                            "AttributeId": "Operation"
                                        },
                                        {
                                            "Actor": "Operation",
                                            "AttributeId": "Disposition"
                                        },
                                        {
                                            "Actor": "Target",
                                            "AttributeId": "IpProtocol"
                                        },
                                        {
                                            "Actor": "Target",
                                            "AttributeId": "LocalPort"
                                        },
                                        {
                                            "Actor": "Target",
                                            "AttributeId": "NetworkFlags"
                                        },
                                        {
                                            "Actor": "Target",
                                            "AttributeId": "IpProtoVersion"
                                        },
                                        {
                                            "Actor": "Target",
                                            "AttributeId": "LocalIpAddress"
                                        }
                                    ]
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "Comment": "maps to Pb evnets: ACTION_CONNECTION_LISTEN (UAV-552)",
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "NET_LISTEN"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Network"
                            }
                        ],
                        "Target": [
                            {
                                "AttributeId": "IpProtocol",
                                "Equals": 6
                            },
                            {
                                "AttributeId": "IpProtocol",
                                "Equals": 17
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "IpProtocol"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "LocalPort"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "NetworkFlags"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "IpProtoVersion"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "LocalIpAddress"
                            }
                        ]
                    }
                ],
                "ReportedAttributeIds": [
                    {
                        "Actor": "Operation",
                        "AttributeId": "Operation"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "Disposition"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "DesiredAccess"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "GrantedAccess"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "RuleType"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "TargetType"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "Timestamp"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FilePath"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileSignatureState"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileSignatureIssuer"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileSignaturePublisher"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileSignatureTimestamp"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileReputation"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "SHA-256"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "MD5"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "DeviceType"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "FilePath"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "FileSignatureState"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "FileSignatureIssuer"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "FileSignaturePublisher"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "FileSignatureTimestamp"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "FileReputation"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "SHA-256"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "MD5"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "DeviceType"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FilePath"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileNewPath"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileReputation"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "SHA-256"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "MD5"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "DeviceType"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "FilePath"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "FileSignatureState"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "FileSignatureIssuer"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "FileSignaturePublisher"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "FileSignatureTimestamp"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "FileReputation"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "SHA-256"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "MD5"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "DeviceType"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileType"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "WriteCount"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "FirstWriteTimestamp"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "FirstWriteOffset"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "FirstWriteSize"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "LastWriteTimestamp"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "LastWriteOffset"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "LastWriteSize"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ProcessCmdLine"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ThreadID"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ProcessID"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ProcessCreateTime"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "PIDNamespaceID"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "UserID"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ProcessStateMachine"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "ProcessCmdLine"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "ThreadID"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "ProcessID"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "ProcessCreateTime"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "PIDNamespaceID"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "UserID"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "ProcessStateMachine"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ProcessCmdLine"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ThreadID"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ProcessID"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ProcessCreateTime"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "PIDNamespaceID"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "UserID"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ProcessStateMachine"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "ProcessCmdLine"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "ThreadID"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "ProcessID"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "ProcessCreateTime"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "PIDNamespaceID"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "UserID"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "ProcessStateMachine"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "IsInitiator"
                    }
                ]
            },
            {
                "GUID": "AAD0574A-A119-4330-83FC-FA8401AC06CB",
                "ProductGUIDs": [
                    "E7A89D11-37FC-4EC1-BB62-34C28CF14221"
                ],
                "Description": "Unified Binary Store (UBS) upload policy",
                "Revision": 7,
                "PolicyTags": "UBS",
                "Enabled": true,
                "AccessCheckRules": [
                    {
                        "Description": "Detect file modification and wait for COW to finish",
                        "GUID": "79ACC775-321F-4F19-A46D-EB86E0249D13",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "Ask",
                                "Context": {
                                    "Reaction": "UbsWriteDetected",
                                    "Actor": "Target"
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "FILE_WRITE",
                                    "FILE_DELETE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "File"
                            }
                        ],
                        "Target": [
                            {
                                "AttributeId": "FileTags",
                                "MatchAnyBits": "FileCopyOnWrite"
                            }
                        ]
                    }
                ],
                "EventCheckRules": [
                    {
                        "Description": "UBS upload triggering rule",
                        "GUID": "3DBDB5F4-A681-401A-8C66-C09E5E8F1564",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "Ask",
                                "Context": {
                                    "Reaction": "UbsUpload",
                                    "Actor": "Target",
                                    "UbsUpload": {
                                        "MaxUploadSizeInBytes": 25000000
                                    }
                                }
                            }
                        ],
                        "Target": [
                            {
                                "AttributeId": "FilePath",
                                "Equals": "**"
                            },
                            {
                                "AttributeId": "FileCloudCopySize",
                                "Exclude": true,
                                "GTE": 25000000
                            },
                            {
                                "AttributeId": "FileTags",
                                "MatchNoneBits": [
                                    "FileCloudCopyIsOriginal"
                                ]
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Operation",
                                "MatchAllBits": [
                                    "FILE_UBS_QUERY_RESPONSE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "File"
                            }
                        ]
                    },
                    {
                        "Description": "Report process create operations",
                        "GUID": "403DF2E3-2053-4d60-9D05-C41C1B99FEE9",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Set 1 or Increment",
                                "AttributeId": "FileStateMachine",
                                "Tags": "FileExecuteCount",
                                "Actor": "Target"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "AttributeId": "ProcessID",
                                "NotEquals": 0
                            },
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Disposition",
                                "Equals": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "CREATE_PROCESS",
                                    "PROCESS_DISCOVERED"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Process"
                            }
                        ],
                        "Target": [
                            {
                                "Comment": "limit to binaries < 512mb until backend can handle hash annotation (UAV-555)",
                                "AttributeId": "FileSize",
                                "LTE": 536870912
                            },
                            {
                                "AttributeId": "FileStateMachine",
                                "MatchNoneBits": [
                                    "FileExecuteCount"
                                ]
                            }
                        ]
                    },
                    {
                        "Description": "Report modload operations",
                        "GUID": "AA0C69F3-2D9F-45de-A892-6B8BE3C4C067",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Set 1 or Increment",
                                "AttributeId": "FileStateMachine",
                                "Tags": "FileExecuteCount",
                                "Actor": "Target"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "AttributeId": "ProcessID",
                                "NotEquals": 0
                            },
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Disposition",
                                "Equals": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "LOAD_IMAGE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Module"
                            }
                        ],
                        "Target": [
                            {
                                "Comment": "limit to binaries < 512mb until backend can handle hash annotation (UAV-555)",
                                "AttributeId": "FileSize",
                                "LTE": 536870912
                            },
                            {
                                "AttributeId": "FileStateMachine",
                                "MatchNoneBits": [
                                    "FileExecuteCount"
                                ]
                            },
                            {
                                "Comment": "Suppress known dll modload events (UAV-502)",
                                "AttributeId": "IsKnownDll",
                                "NotEquals": true
                            },
                            {
                                "Comment": "Suppress process image modload event (UAV-395)",
                                "AttributeId": "FilePath",
                                "CompareValues": {
                                    "NotEqualsCaseSensitive": {
                                        "Actor": "Initiator",
                                        "AttributeId": "FilePath"
                                    }
                                }
                            }
                        ]
                    },
                    {
                        "Description": "Send UBS query for process create operations",
                        "GUID": "A4B3FA73-AD5F-4bd1-BFF7-7EBA4B52C0FD",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "Ask",
                                "Context": {
                                    "Reaction": "UbsQuery",
                                    "Actor": "Target",
                                    "UbsQuery": {
                                        "MaxUploadSizeInBytes": 25000000
                                    }
                                }
                            },
                            {
                                "Reaction": "Tag Set",
                                "Tags.Target.FileTags": "FileCopyOnWrite"
                            }
                        ],
                        "Initiator": [
                            {
                                "AttributeId": "ProcessID",
                                "NotEquals": 0
                            },
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Disposition",
                                "Equals": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "CREATE_PROCESS",
                                    "PROCESS_DISCOVERED"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Process"
                            }
                        ],
                        "Target": [
                            {
                                "Comment": "limit to binaries < 512mb until backend can handle hash annotation (UAV-555)",
                                "AttributeId": "FileSize",
                                "LTE": 536870912
                            },
                            {
                                "AttributeId": "FileSignatureState",
                                "MatchNoneBits": [
                                    "FILE_SIGNATURE_STATE_OS"
                                ]
                            },
                            {
                                "AttributeId": "FileStateMachine",
                                "MatchNoneBits": [
                                    "FileExecuteCount"
                                ]
                            }
                        ]
                    },
                    {
                        "Description": "Clear copy-on-write flag",
                        "GUID": "DED2B872-ABC4-4D86-9EB7-DF992C60D448",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "Tag Remove",
                                "Tags.Target.FileTags": "FileCopyOnWrite"
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": "FILE_UBS_COW_DONE"
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "File"
                            }
                        ],
                        "Target": [
                            {
                                "AttributeId": "FileTags",
                                "MatchAnyBits": "FileCopyOnWrite"
                            }
                        ]
                    },
                    {
                        "Description": "Send UBS query for modload operations",
                        "GUID": "C68F6D61-4368-4e7e-BDF7-77901558AF30",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "Ask",
                                "Context": {
                                    "Reaction": "UbsQuery",
                                    "Actor": "Target",
                                    "UbsQuery": {
                                        "MaxUploadSizeInBytes": 25000000
                                    }
                                }
                            },
                            {
                                "Reaction": "Tag Set",
                                "Tags.Target.FileTags": "FileCopyOnWrite"
                            }
                        ],
                        "Initiator": [
                            {
                                "AttributeId": "ProcessID",
                                "NotEquals": 0
                            },
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Disposition",
                                "Equals": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "LOAD_IMAGE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Module"
                            }
                        ],
                        "Target": [
                            {
                                "Comment": "limit to binaries < 512mb until backend can handle hash annotation (UAV-555)",
                                "AttributeId": "FileSize",
                                "LTE": 536870912
                            },
                            {
                                "AttributeId": "FileStateMachine",
                                "MatchNoneBits": [
                                    "FileExecuteCount"
                                ]
                            },
                            {
                                "Comment": "Suppress known dll modload events (UAV-502)",
                                "AttributeId": "IsKnownDll",
                                "NotEquals": true
                            },
                            {
                                "Comment": "Suppress signed Windows binaries (UAV-567)",
                                "AttributeId": "FileSignatureState",
                                "MatchNoneBits": [
                                    "FILE_SIGNATURE_STATE_OS"
                                ]
                            },
                            {
                                "Comment": "Suppress process image modload event (UAV-395)",
                                "AttributeId": "FilePath",
                                "CompareValues": {
                                    "NotEqualsCaseSensitive": {
                                        "Actor": "Initiator",
                                        "AttributeId": "FilePath"
                                    }
                                }
                            }
                        ]
                    }
                ],
                "ReportedAttributeIds": [
                    {
                        "Actor": "Operation",
                        "AttributeId": "Operation"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "Disposition"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "DesiredAccess"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "GrantedAccess"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "RuleType"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "TargetType"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "Timestamp"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FilePath"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileSignatureState"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileSignatureIssuer"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileSignaturePublisher"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileSignatureTimestamp"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileReputation"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FilePath"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileSignatureState"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileSignatureIssuer"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileSignaturePublisher"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileSignatureTimestamp"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileReputation"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileSize"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileArchitecture"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceCompany"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceProduct"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceInternalName"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceCopyright"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceTrademark"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceFileDescription"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceVersion"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceComments"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceOriginalFilename"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceProductDescription"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceProductVersion"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourcePrivateBuild"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceSpecialBuild"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceLangId"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileResourceCharsetId"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "SHA-256"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "MD5"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "DeviceType"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ProcessCmdLine"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ThreadID"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ProcessID"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ProcessCreateTime"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "PIDNamespaceID"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "UserID"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "SHA-256"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "MD5"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "DeviceType"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ProcessCmdLine"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ThreadID"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ProcessID"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ProcessCreateTime"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "PIDNamespaceID"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "UserID"
                    }
                ]
            }
        ]
  }',
          '{
        "$schema": "http://json-schema.org/schema#",
        "id": "CbPscThRules-2018-12-03.json",
        "Version": "1.0",
        "Policies": [
            {
                "GUID": "19EF3154-298C-4257-B2E0-CB548FDD8909",
                "ProductGUIDs": [
                    "E7A89D11-37FC-4EC1-BB62-34C28CF14221"
                ],
                "Description": "PSC Response Policy",
                "Revision": 10,
                "PolicyTags": "PSCR",
                "Enabled": true,
                "EventCheckRules": [
                    {
                        "Description": "Report file create, open for w/d, delete, undelete and rename for files without signer metadata",
                        "GUID": "3D31EB6E-EF60-416A-B931-437F9D274821",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessFileModCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "Comment": "Since STATUS_REPARSE is ignored by the sensor, we can write the rule to be NT_SUCCESS(status)",
                                "AttributeId": "Disposition",
                                "GTE": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "FILE_CREATE",
                                    "FILE_OPEN_WRITE",
                                    "FILE_OPEN_DELETE",
                                    "FILE_DELETE",
                                    "FILE_UNDELETE",
                                    "FILE_RENAME",
                                    "FILE_TRUNCATE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "File"
                            }
                        ],
                        "Target": [
                            {
                                "AttributeId": "FileType",
                                "Equals": [
                                    "FILE_TYPE_EXECUTABLE_IMAGE",
                                    "FILE_TYPE_EXECUTABLE_DLL"
                                ],
                                "Exclude": true
                            },
                            {
                                "AttributeId": "FileExtension",
                                "Equals": [
                                    "ps1",
                                    "psm1",
                                    "cdxml",
                                    "msi",
                                    "msp",
                                    "mst"
                                ],
                                "Exclude": true
                            }
                        ]
                    },
                    {
                        "Description": "Report file create, open for w/d, delete, undelete and rename for PE files",
                        "GUID": "DD0C81A3-04D3-453E-AF99-56AB86F577A0",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessFileModCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "Comment": "Since STATUS_REPARSE is ignored by the sensor, we can write the rule to be NT_SUCCESS(status)",
                                "AttributeId": "Disposition",
                                "GTE": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "FILE_CREATE",
                                    "FILE_OPEN_WRITE",
                                    "FILE_OPEN_DELETE",
                                    "FILE_DELETE",
                                    "FILE_UNDELETE",
                                    "FILE_RENAME",
                                    "FILE_TRUNCATE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "File"
                            }
                        ],
                        "Target": [
                            {
                                "AttributeId": "FileType",
                                "Equals": [
                                    "FILE_TYPE_EXECUTABLE_IMAGE",
                                    "FILE_TYPE_EXECUTABLE_DLL"
                                ]
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report file create, open for w/d, delete, undelete and rename for non-PE files that can have signer data",
                        "GUID": "0B32C6E5-A01D-41C5-A6E2-86AFEAFDD460",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessFileModCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "Comment": "Since STATUS_REPARSE is ignored by the sensor, we can write the rule to be NT_SUCCESS(status)",
                                "AttributeId": "Disposition",
                                "GTE": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "FILE_CREATE",
                                    "FILE_OPEN_WRITE",
                                    "FILE_OPEN_DELETE",
                                    "FILE_DELETE",
                                    "FILE_UNDELETE",
                                    "FILE_RENAME",
                                    "FILE_TRUNCATE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "File"
                            }
                        ],
                        "Target": [
                            {
                                "AttributeId": "FileExtension",
                                "Equals": [
                                    "ps1",
                                    "psm1",
                                    "cdxml",
                                    "msi",
                                    "msp",
                                    "mst"
                                ]
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report file last write",
                        "GUID": "3D2396F4-71AC-496A-9A5A-53A6ECC7AD1A",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Set 1 or Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessFileModCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "FILE_LAST_WRITE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "File"
                            }
                        ],
                        "Target": [
                            {
                                "Comment": "Restrict matches to executable file types (UAV-564)",
                                "AttributeId": "FileType",
                                "Equals": [
                                    "FILE_TYPE_EXECUTABLE_IMAGE",
                                    "FILE_TYPE_EXECUTABLE_DLL"
                                ]
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report registry operations",
                        "GUID": "219833E7-914E-4E0E-886C-63E7DE7853EC",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessRegModCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Disposition",
                                "Equals": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "REG_CREATE_KEY",
                                    "REG_DELETE_KEY",
                                    "REG_DELETE_VALUE",
                                    "REG_WRITE_VALUE",
                                    "REG_RENAME_KEY",
                                    "REG_REPLACE_KEY",
                                    "REG_RESTORE_KEY",
                                    "REG_LOAD_KEY"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Registry"
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "RegKeyValuePath"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "RegNewKeyPath"
                            }
                        ]
                    },
                    {
                        "Description": "Report process create operations",
                        "GUID": "7B209D10-FD28-469f-8912-F16D0C34433D",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessCreateCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "State Set",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": [
                                    "ProcessModuleLoadCount",
                                    "ProcessFileModCount",
                                    "ProcessNetConnCount",
                                    "ProcessRegModCount",
                                    "ProcessCreateCount",
                                    "ProcessCrossProcessCount",
                                    "ProcessCrossProcessTargetCount"
                                ],
                                "Actor": "Target",
                                "StateValue": 0
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Disposition",
                                "Equals": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "CREATE_PROCESS",
                                    "PROCESS_DISCOVERED"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Process"
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report process termination",
                        "GUID": "6D0B2BF2-BD3B-4768-8E51-2C350985BBB7",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Set 1 or Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessCrossProcessCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "AttributeId": "ProcessID",
                                "NotEquals": 0
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "PROCESS_TERMINATE"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Process"
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report process and thread operations",
                        "GUID": "0E5F8A39-1BB2-4A4E-942E-2618A41ABB24",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessCrossProcessCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessCrossProcessTargetCount",
                                "Actor": "Target"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "AttributeId": "FilePath",
                                "Exclude": true,
                                "Equals": "<System>\\csrss.exe"
                            },
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Disposition",
                                "Equals": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "OPEN_PROCESS_HANDLE",
                                    "OPEN_THREAD_HANDLE",
                                    "DUP_PROCESS_HANDLE",
                                    "DUP_THREAD_HANDLE",
                                    "CREATE_REMOTE_THREAD"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Process"
                            }
                        ],
                        "TargetParent": [
                            {
                                "AttributeId": "IsInitiator",
                                "Exclude": true,
                                "Equals": true
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report module and script load operations",
                        "GUID": "6F04362F-23BA-45E0-875A-BB686EA7F65C",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessModuleLoadCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "AttributeId": "ProcessID",
                                "NotEquals": 0
                            }
                        ],
                        "Operation": [
                            {
                                "AttributeId": "Disposition",
                                "GTE": 0
                            },
                            {
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "LOAD_IMAGE",
                                    "LOAD_SCRIPT"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Module"
                            }
                        ],
                        "Target": [
                            {
                                "Comment": "Suppress known dll modload events (UAV-502)",
                                "AttributeId": "IsKnownDll",
                                "NotEquals": true
                            },
                            {
                                "Comment": "Suppress process image modload event (UAV-395)",
                                "AttributeId": "FilePath",
                                "CompareValues": {
                                    "NotEqualsCaseSensitive": {
                                        "Actor": "Initiator",
                                        "AttributeId": "FilePath"
                                    }
                                }
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureState"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureIssuer"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignaturePublisher"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "FileSignatureTimestamp"
                            }
                        ]
                    },
                    {
                        "Description": "Report network operations",
                        "GUID": "FDDAD7FC-9B5A-4BAC-AE2E-EA841AF6B27A",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessNetConnCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "UseDefaults": 1
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "Comment": "maps to Pb evnets: ACTION_CONNECTION_CREATE, ACTION_CONNECTION_CREATE_FAILED (UAV-552)",
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "NET_ACCEPT",
                                    "NET_CONNECT",
                                    "NET_CONNECT_FAILED"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Network"
                            }
                        ],
                        "Target": [
                            {
                                "AttributeId": "IpProtocol",
                                "Equals": 6
                            },
                            {
                                "AttributeId": "IpProtocol",
                                "Equals": 17
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "IpProtocol"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "LocalPort"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "RemotePort"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "Fqdn"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "NetworkFlags"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "IpProtoVersion"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "LocalIpAddress"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "RemoteIpAddress"
                            }
                        ]
                    },
                    {
                        "Description": "Report network listen",
                        "GUID": "EDDAD7FC-9B5A-4BAC-AE2E-EA841AF6B27A",
                        "NonTerminalReactions": [
                            {
                                "Reaction": "State Increment",
                                "AttributeId": "ProcessStateMachine",
                                "Tags": "ProcessNetConnCount",
                                "Actor": "Initiator"
                            },
                            {
                                "Reaction": "Report",
                                "Flags": [
                                    "ReportAsync"
                                ],
                                "Destination": [
                                    "DESTINATION_CLOUD"
                                ]
                            }
                        ],
                        "Initiator": [
                            {
                                "UniqueValues": {
                                    "ValuesOf": [
                                        {
                                            "Actor": "Operation",
                                            "AttributeId": "Operation"
                                        },
                                        {
                                            "Actor": "Operation",
                                            "AttributeId": "Disposition"
                                        },
                                        {
                                            "Actor": "Target",
                                            "AttributeId": "IpProtocol"
                                        },
                                        {
                                            "Actor": "Target",
                                            "AttributeId": "LocalPort"
                                        },
                                        {
                                            "Actor": "Target",
                                            "AttributeId": "NetworkFlags"
                                        },
                                        {
                                            "Actor": "Target",
                                            "AttributeId": "IpProtoVersion"
                                        },
                                        {
                                            "Actor": "Target",
                                            "AttributeId": "LocalIpAddress"
                                        }
                                    ]
                                }
                            }
                        ],
                        "Operation": [
                            {
                                "Comment": "maps to Pb evnets: ACTION_CONNECTION_LISTEN (UAV-552)",
                                "AttributeId": "Operation",
                                "MatchAnyBits": [
                                    "NET_LISTEN"
                                ]
                            },
                            {
                                "AttributeId": "TargetType",
                                "Equals": "Network"
                            }
                        ],
                        "Target": [
                            {
                                "AttributeId": "IpProtocol",
                                "Equals": 6
                            },
                            {
                                "AttributeId": "IpProtocol",
                                "Equals": 17
                            }
                        ],
                        "ReportedAttributeIds": [
                            {
                                "Actor": "Target",
                                "AttributeId": "IpProtocol"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "LocalPort"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "NetworkFlags"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "IpProtoVersion"
                            },
                            {
                                "Actor": "Target",
                                "AttributeId": "LocalIpAddress"
                            }
                        ]
                    }
                ],
                "ReportedAttributeIds": [
                    {
                        "Actor": "Operation",
                        "AttributeId": "Operation"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "Disposition"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "DesiredAccess"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "GrantedAccess"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "RuleType"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "TargetType"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "Timestamp"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FilePath"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileSignatureState"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileSignatureIssuer"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileSignaturePublisher"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileSignatureTimestamp"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "FileReputation"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "SHA-256"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "MD5"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "DeviceType"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "FilePath"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "FileSignatureState"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "FileSignatureIssuer"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "FileSignaturePublisher"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "FileSignatureTimestamp"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "FileReputation"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "SHA-256"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "MD5"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "DeviceType"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FilePath"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileNewPath"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileReputation"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "SHA-256"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "MD5"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "DeviceType"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "FilePath"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "FileSignatureState"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "FileSignatureIssuer"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "FileSignaturePublisher"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "FileSignatureTimestamp"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "FileReputation"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "SHA-256"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "MD5"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "DeviceType"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "FileType"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "WriteCount"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "FirstWriteTimestamp"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "FirstWriteOffset"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "FirstWriteSize"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "LastWriteTimestamp"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "LastWriteOffset"
                    },
                    {
                        "Actor": "Operation",
                        "AttributeId": "LastWriteSize"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ProcessCmdLine"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ThreadID"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ProcessID"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ProcessCreateTime"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "PIDNamespaceID"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "UserID"
                    },
                    {
                        "Actor": "Initiator",
                        "AttributeId": "ProcessStateMachine"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "ProcessCmdLine"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "ThreadID"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "ProcessID"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "ProcessCreateTime"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "PIDNamespaceID"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "UserID"
                    },
                    {
                        "Actor": "Parent",
                        "AttributeId": "ProcessStateMachine"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ProcessCmdLine"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ThreadID"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ProcessID"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ProcessCreateTime"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "PIDNamespaceID"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "UserID"
                    },
                    {
                        "Actor": "Target",
                        "AttributeId": "ProcessStateMachine"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "ProcessCmdLine"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "ThreadID"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "ProcessID"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "ProcessCreateTime"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "PIDNamespaceID"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "UserID"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "ProcessStateMachine"
                    },
                    {
                        "Actor": "TargetParent",
                        "AttributeId": "IsInitiator"
                    }
                ]
            }
        ]
  }',
          'Default TH Rules');

END IF;
END
$do$;
