--
-- CBC-10015 - Removing the constraint on table connector_identity, field identity_key to be UNIQUE
-- to allow for shared OAuth apps to be supported in the future. New constraint added for the combination of org_id and
-- identity_key to be unique as we want to allow on OAuth app to be registered only once for a single organization
--

ALTER TABLE connector_identity
  DROP CONSTRAINT IF EXISTS connector_identity_identity_key_key;

ALTER TABLE connector_identity
  ADD UNIQUE (org_id, identity_key);

--
-- DSER-35281
-- Migrating existing emails to lowercase to optimize searches for email ids
--

UPDATE admin_registration
    SET email_id = LOWER(email_id);

UPDATE admin_login
    SET login_name = LOWER(login_name);

CREATE OR REPLACE FUNCTION lowercase_email() RETURNS TRIGGER
AS $lowercase_email$
BEGIN
    NEW.email_id = LOWER(NEW.email_id);
    RETURN NEW;
END;
$lowercase_email$
LANGUAGE plpgsql;

CREATE OR REPLACE FUNCTION lowercase_login_name() RETURNS TRIGGER
AS $lowercase_login_name$
BEGIN
    NEW.login_name = LOWER(NEW.login_name);
    RETURN NEW;
END;
$lowercase_login_name$
LANGUAGE plpgsql;

CREATE TRIGGER lowercase_email
    BEFORE INSERT OR UPDATE
    ON admin_registration
    FOR EACH ROW
    EXECUTE PROCEDURE lowercase_email();

CREATE TRIGGER lowercase_login_name
    BEFORE INSERT OR UPDATE
    ON admin_login
    FOR EACH ROW
EXECUTE PROCEDURE lowercase_login_name();


ALTER TABLE admin_registration
    ADD CHECK(email_id = LOWER(email_id));

ALTER TABLE admin_login
    ADD CHECK(login_name = LOWER(login_name));

